tmux

package module
v0.0.0-...-4fe1909 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jul 21, 2026 License: MIT Imports: 21 Imported by: 0

Documentation

Overview

Package tmux implements generic typed terminal sessions over tmux control mode. The same provider is compiled in or served out of process and is reachable through every Charly provider transport, including gRPC tunneled through SSH and tmux sessions placed behind gRPC target hops.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func NewMeta

func NewMeta() pb.PluginMetaServer

NewMeta advertises the two typed streaming capabilities.

func NewProvider

func NewProvider() pb.ProviderServer

NewProvider returns the tmux provider.

Types

This section is empty.

Directories

Path Synopsis
cmd
serve command
Command serve is the out-of-process placement of the same typed terminal provider that can be compiled into charly.
Command serve is the out-of-process placement of the same typed terminal provider that can be compiled into charly.

Jump to